OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s añadida por el sistema",
    "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Se añadió la etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s añadió la etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} añadió la etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s eliminada por el sistema",
    "Removed system tag {systemtag}" : "Eliminada etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminada etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creó la etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted eliminó la etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted eliminó la etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminó la etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminó la etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta de sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$s  añadida a %1$s por el sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} añadida a {file} por el sistema",
    "You added system tag %2$s to %1$s" : "Usted añadió la etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted añadió la etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s eliminada de %1$s por el sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} eliminada de {file} por el sistema",
    "You removed system tag %2$s from %1$s" : "Ha removido la etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Ha removido la etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removió la etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removió la etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "Se han modificado las <strong>etiquetas de sistema</strong> de un archivo",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos etiquetados %s …",
    "tagged %s" : "Etiquetados %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Create or edit tags" : "Crear o editar etiquetas",
    "Search for a tag to edit" : "Buscar la etiqueta a editar",
    "Collaborative tags …" : "Etiquetas colaborativas ...",
    "No tags to select" : "No hay etiquetas para seleccionar",
    "Tag name" : "Nombre de la etiqueta",
    "Tag level" : "Nivel de la etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Borrar",
    "Reset" : "Restablecer",
    "Loading …" : "Cargando …",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Fallo al crear etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "Fallo al actualizar la etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "Fallo al borrar etiqueta",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas …",
    "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escriba para crear una etiqueta nueva",
    "Failed to load tags" : "Fallo al cargar etiquetas",
    "Failed to load selected tags" : "Fallo al cargar las etiquetas seleccionadas",
    "Failed to select tag" : "Fallo al seleccionar etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
    "List of tags and their associated files and folders." : "Lista de etiquetas y sus carpetas y archivos asociados.",
    "No tags found" : "No se encontraron etiquetas",
    "Tags you have created will show up here." : "Las etiquetas que haya creado aparecerán aquí.",
    "Failed to load last used tags" : "Fallo al cargar las etiquetas recientemente utilizadas",
    "Missing \"Content-Location\" header" : "No existe la cabecera \"Content-Location\"",
    "Failed to load tags for file" : "Fallo al cargar las etiquetas del archivo",
    "Failed to set tag for file" : "Fallo al asignar la etiqueta al archivo",
    "Failed to delete tag for file" : "Fallo al borrar la etiqueta del archivo",
    "Tag name is empty" : "El nombre de la etiqueta está vacío",
    "Select tag …" : "Selecciona etiqueta...",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios. Adecuado para equipos.\n\n(Si eres un proveedor con una instalación en multitenencia), se aconseja desactivar esta app pues las etiquetas se comparten).",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Seleccionar etiquetas por las que filtrar",
    "Please select tags to filter by" : "Por favor, seleccione las etiquetas por las que desea filtrar",
    "No files found for the selected tags" : "No se han encontrado archivos para las etiquetas seleccionadas",
    "Create a new tag" : "Crear una etiqueta nueva",
    "Name" : "Nombre",
    "No files in here" : "Aquí no hay archivos",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
